summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/kopeteeditglobalidentitywidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/kopeteeditglobalidentitywidget.h')
-rw-r--r--kopete/kopete/kopeteeditglobalidentitywidget.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/kopete/kopeteeditglobalidentitywidget.h b/kopete/kopete/kopeteeditglobalidentitywidget.h
index 00f1d7fc..82ad3ca7 100644
--- a/kopete/kopete/kopeteeditglobalidentitywidget.h
+++ b/kopete/kopete/kopeteeditglobalidentitywidget.h
@@ -35,12 +35,12 @@ class KopeteEditGlobalIdentityWidget : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- KopeteEditGlobalIdentityWidget(TQWidget *tqparent = 0, const char *name = 0);
+ KopeteEditGlobalIdentityWidget(TQWidget *parent = 0, const char *name = 0);
virtual ~KopeteEditGlobalIdentityWidget();
public slots:
/**
* This slot is called when the "tqparent" toolbar change its icon size.
*/
void iconSizeChanged();
/**
@@ -89,7 +89,7 @@ class ClickableLabel : public TQLabel
Q_OBJECT
TQ_OBJECT
public:
- ClickableLabel(TQWidget *tqparent = 0, const char *name = 0);
+ ClickableLabel(TQWidget *parent = 0, const char *name = 0);
signals:
void clicked();
@@ -35,12 +35,12 @@ class KopeteEditGlobalIdentityWidget : public TQWidget
public slots:
/**
- * This slot is called when the "tqparent" toolbar change its icon size.
+ * This slot is called when the "parent" toolbar change its icon size.
*/
void iconSizeChanged();